==> prize-center-api-1.1.6-sources.jar: cn/com/duiba/prize/center/api/params/prize/DuibaItemCheckPrizeParam.java <==
package cn.com.duiba.prize.center.api.params.prize;

import java.io.Serializable;

/**
 * 奖品校验参数
 * Created by sunchangji on 2018/4/14.
 */
public class DuibaItemCheckPrizeParam implements Serializable {
    private static final long serialVersionUID = 6808626322402747855L;

    /**
     * 开发者id
     */
    private Long developerId;

    /**
     * 应用id
     */
    private Long appId;

    private Long itemId;

    private Long appItemId;

    private String partnerUserId;

    private String facePrice;

    private String orderId;

    private String ip;

    private Long activityId;

    private boolean checkFlag;

    private String logType;

    /**
     * cn.com.duiba.activity.common.center.api.enums.consumeraccounts.AccountBizTypeEnum
     */
    private Integer accountBizType;

    /**
     * 奖品类型 在ItemDO中
     */
    private String prizeType;

    /**
     * 虚拟商品充值接口
     */
    private String virtualExchangeUrl;

    /**
     * 兑吧app状态位
     */
    private Long appSwitch;
    
    // tongchujiang shiyong 
    private Integer activityType;
    /**
     * 活动类型
     * @see cn.com.duiba.api.enums.ActivityUniformityTypeEnum
     */
    private Integer activityUniformityType;

    public Long getDeveloperId() {
        return developerId;
    }

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public String getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(String facePrice) {
        this.facePrice = facePrice;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public boolean getCheckFlag() {
        return checkFlag;
    }

    public void setCheckFlag(boolean checkFlag) {
        this.checkFlag = checkFlag;
    }

    public String getLogType() {
        return logType;
    }

    public void setLogType(String logType) {
        this.logType = logType;
    }

    public Integer getAccountBizType() {
        return accountBizType;
    }

    public void setAccountBizType(Integer accountBizType) {
        this.accountBizType = accountBizType;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getVirtualExchangeUrl() {
        return virtualExchangeUrl;
    }

    public void setVirtualExchangeUrl(String virtualExchangeUrl) {
        this.virtualExchangeUrl = virtualExchangeUrl;
    }

    public Long getAppSwitch() {
        return appSwitch;
    }

    public void setAppSwitch(Long appSwitch) {
        this.appSwitch = appSwitch;
    }

	public Integer getActivityType() {
		return activityType;
	}

	public void setActivityType(Integer activityType) {
		this.activityType = activityType;
	}

    public Integer getActivityUniformityType() {
        return activityUniformityType;
    }

    public void setActivityUniformityType(Integer activityUniformityType) {
        this.activityUniformityType = activityUniformityType;
    }
}

==> prize-center-api-1.1.11-sources.jar: cn/com/duiba/prize/center/api/params/prize/DuibaItemCheckPrizeParam.java <==
package cn.com.duiba.prize.center.api.params.prize;

import java.io.Serializable;

/**
 * 奖品校验参数
 * Created by sunchangji on 2018/4/14.
 */
public class DuibaItemCheckPrizeParam implements Serializable {
    private static final long serialVersionUID = 6808626322402747855L;

    /**
     * 开发者id
     */
    private Long developerId;

    /**
     * 应用id
     */
    private Long appId;

    private Long itemId;

    private Long appItemId;

    private String partnerUserId;

    private String facePrice;

    private String orderId;

    private String ip;

    private Long activityId;

    private boolean checkFlag;

    private String logType;

    /**
     * cn.com.duiba.activity.common.center.api.enums.consumeraccounts.AccountBizTypeEnum
     */
    private Integer accountBizType;

    /**
     * 奖品类型 在ItemDO中
     */
    private String prizeType;

    /**
     * 虚拟商品充值接口
     */
    private String virtualExchangeUrl;

    /**
     * 兑吧app状态位
     */
    private Long appSwitch;
    
    // tongchujiang shiyong 
    private Integer activityType;
    /**
     * 活动类型
     * @see cn.com.duiba.api.enums.ActivityUniformityTypeEnum
     */
    private Integer activityUniformityType;

    /**
     * 扣开发者余额 0 扣兑吧，1：扣开发者  默认0
     * */
    private Integer useDevBalance;

    public Long getDeveloperId() {
        return developerId;
    }

    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public String getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(String facePrice) {
        this.facePrice = facePrice;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public boolean getCheckFlag() {
        return checkFlag;
    }

    public void setCheckFlag(boolean checkFlag) {
        this.checkFlag = checkFlag;
    }

    public String getLogType() {
        return logType;
    }

    public void setLogType(String logType) {
        this.logType = logType;
    }

    public Integer getAccountBizType() {
        return accountBizType;
    }

    public void setAccountBizType(Integer accountBizType) {
        this.accountBizType = accountBizType;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getVirtualExchangeUrl() {
        return virtualExchangeUrl;
    }

    public void setVirtualExchangeUrl(String virtualExchangeUrl) {
        this.virtualExchangeUrl = virtualExchangeUrl;
    }

    public Long getAppSwitch() {
        return appSwitch;
    }

    public void setAppSwitch(Long appSwitch) {
        this.appSwitch = appSwitch;
    }

	public Integer getActivityType() {
		return activityType;
	}

	public void setActivityType(Integer activityType) {
		this.activityType = activityType;
	}

    public Integer getActivityUniformityType() {
        return activityUniformityType;
    }

    public void setActivityUniformityType(Integer activityUniformityType) {
        this.activityUniformityType = activityUniformityType;
    }

    public Integer getUseDevBalance() {
        return useDevBalance;
    }

    public void setUseDevBalance(Integer useDevBalance) {
        this.useDevBalance = useDevBalance;
    }
}
